snapkitty
hardware
erlang
File size: 22,415 Bytes
b8a03fa
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
 
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
# Meta Tool Catalog

This file is a grounded inventory of the tool surface available right now.

It is split into three layers:

1. Live Codex tools available in this session
2. Installed skills and connectors available to this environment
3. Open-source app and workflow surfaces discovered in the local workspace

This is not a claim about "every tool any AI has ever used on earth." That is not enumerable from local evidence. This is the honest, source-backed catalog of what is available here.

## 1. Live Codex Tool Surface

These are the tools exposed directly to this Codex session.

### Built-in web and media

- `web.search_query` - internet search
- `web.open` - open search results or URLs
- `web.click` - follow links on opened pages
- `web.find` - find text on opened pages
- `web.screenshot` - PDF screenshots
- `web.image_query` - image search
- `web.finance` - market quotes
- `web.weather` - weather lookup
- `web.sports` - schedules and standings
- `web.time` - timezone lookup
- `image_gen.imagegen` - generate or edit bitmap images

### Local execution and editing

- `functions.exec_command` - shell execution
- `functions.write_stdin` - interact with running shell sessions
- `functions.apply_patch` - edit files safely with patches
- `functions.view_image` - inspect local images
- `functions.load_workspace_dependencies` - discover bundled runtimes and libraries

### Planning and orchestration

- `functions.update_plan`
- `functions.get_goal`
- `functions.create_goal`
- `functions.update_goal`
- `functions.request_user_input` only when enabled in mode
- `multi_tool_use.parallel` - parallel developer-tool execution

### MCP and discovery

- `functions.list_mcp_resources`
- `functions.list_mcp_resource_templates`
- `functions.read_mcp_resource`
- `tool_search.tool_search_tool` - deferred tool and connector discovery

### Repo/app navigation

- `codex_app.navigate_to_codex_page`
- `codex_app.read_thread_terminal`

### Plugin management

- `functions.list_available_plugins_to_install`
- `functions.request_plugin_install`

## 2. Installed Skills in This Environment

These are higher-level operating manuals and helper packs available to Codex in this desktop environment.

### Core platform and infra

- `agents-sdk`
- `cloudflare`
- `cloudflare-email-service`
- `cloudflare-one`
- `cloudflare-one-migrations`
- `durable-objects`
- `sandbox-sdk`
- `workers-best-practices`
- `wrangler`
- `turnstile-spin`

### OpenAI and Codex

- `openai-docs`
- `plugin-creator`
- `skill-creator`
- `skill-installer`

### Browser and UI control

- `browser:control-in-app-browser`
- `chrome:control-chrome`
- `web-perf`
- `imagegen`

### Data, docs, and artifacts

- `pdf:pdf`
- `presentations:Presentations`
- `spreadsheets:Spreadsheets`
- `template-creator:template-creator`

### Business and app connectors

- `airtable:airtable-cli`
- `airtable:airtable-filters`
- `airtable:airtable-overview`
- `github:github`
- `github:gh-address-comments`
- `github:gh-fix-ci`
- `github:yeet`
- `linear:linear`
- `slack:slack`
- `slack:slack-channel-summarization`
- `slack:slack-daily-digest`
- `slack:slack-notification-triage`
- `slack:slack-outgoing-message`
- `slack:slack-reply-drafting`
- `canva:canva-branded-presentation`
- `canva:canva-resize-for-all-social-media`
- `canva:canva-translate-design`

### Payments and external service work

- `stripe-best-practices`
- `stripe-projects`
- `upgrade-stripe`

## 3. Workspace-Discovered App Surface

The local workspace includes a resurrected workflow system here:

- [cipher-workflow app catalog](C:\Users\jessi\Desktop\bobs control repo\shadow-orchestrator\.resurrect-workspace\cipher-workflow\src\lib\app-catalog.ts)
- [cipher-workflow node registry](C:\Users\jessi\Desktop\bobs control repo\shadow-orchestrator\.resurrect-workspace\cipher-workflow\src\config\node-components.ts)
- [cipher-workflow logos](C:\Users\jessi\Desktop\bobs control repo\shadow-orchestrator\.resurrect-workspace\cipher-workflow\public\logos)

What is verifiable from source:

- `42` connector/logo assets are present in `public/logos`
- `113` app presets are declared in `app-catalog.ts`
- the universal dialog claims `70+ apps with 400+ operations`
- `39` registered workflow node imports exist in `node-components.ts`

## 4. Workspace Connector Logos

These connectors are visually provisioned in the local workflow stack:

- Airtable
- Anthropic
- Asana
- ClickUp
- Discord
- Dropbox
- Email
- Firebase
- Gemini
- GitHub
- Google
- Google Sheets
- Google Form
- HubSpot
- Instagram
- Jira
- Linear
- LinkedIn
- Mailchimp
- Mistral
- Mixpanel
- Notion
- OpenAI
- Qwen
- RSS
- Salesforce
- SendGrid
- Shopify
- Slack
- SMS
- Spotify
- Stripe
- Supabase
- Telegram
- Trello
- Twitter
- Vercel API
- WhatsApp
- YouTube
- Zendesk
- Zoom

## 5. Implemented Workflow Node Types

These are not just icons. They are registered node types in the local workflow editor.

### Triggers

- Initial
- Manual Trigger
- Google Form Trigger
- Stripe Trigger
- Webhook Trigger
- Schedule Trigger

### AI model nodes

- Gemini
- OpenAI
- Anthropic
- Mistral
- Qwen

### Messaging and social execution

- Discord
- Slack
- Twitter
- Telegram
- LinkedIn
- Instagram
- WhatsApp
- Email
- SMS
- RSS Feed

### Productivity and developer execution

- Notion
- Google Sheets
- GitHub
- HTTP Request
- Universal App Node

### AI utility and chain nodes

- AI Agent
- AI Chain
- Summarizer
- Text Classifier
- Info Extractor
- Output Parser
- Document Loader
- Text Splitter
- AI Memory
- Embeddings
- Vector Store

## 6. Broader App Preset Families Found in Source

The local `app-catalog.ts` goes beyond the visible logos. It includes larger preset families across:

- CRM and sales
- Project management
- Communication
- Cloud storage
- Databases
- E-commerce
- Marketing
- Finance
- Productivity
- Developer tools
- Utilities
- AI and ML

Examples explicitly present in source include:

- HubSpot
- Salesforce
- Pipedrive
- Zoho CRM
- ActiveCampaign
- Copper
- Close CRM
- Freshsales
- Asana
- Jira
- Trello
- ClickUp
- Linear
- Monday.com
- Todoist
- Basecamp
- Zoom
- Calendly
- Cal.com
- Microsoft Teams
- Google Drive
- Dropbox
- Box
- OneDrive
- Airtable
- Supabase
- Firebase
- Shopify
- WooCommerce
- PayPal
- Mailchimp
- SendGrid
- Stripe
- Notion
- Make
- Zapier
- Smartsheet

## 7. What This Means Operationally

You effectively have three concentric layers:

1. Codex-native operator tools
2. Installed connector and skill layer
3. A local open-source workflow catalog that already models a large multi-app automation surface

That means you do not need to treat "tooling" as one thing. You already have:

- agent tooling
- browser tooling
- shell tooling
- editing tooling
- connector tooling
- workflow-node tooling
- webhook-trigger tooling
- universal REST app tooling

## 8. Gaps and Honest Limits

- I cannot prove "every tool AI has ever called on" from local evidence alone.
- Some presets in `app-catalog.ts` may be declared but not fully wired as dedicated first-class nodes.
- Some installed skills are manuals and workflows, not raw callable APIs by themselves.
- Some connectors need credentials before they become usable in practice.

## 9. Recommended Next Catalogs

If you want this pushed further, the next useful splits are:

1. `TOOL_CATALOG_RUNTIME.md` - only tools callable right now without extra credentials
2. `TOOL_CATALOG_CONNECTORS.md` - every third-party integration by auth model and transport
3. `TOOL_CATALOG_AGENTS.md` - every agent role, model endpoint, and workflow node in one matrix
4. `TOOL_CATALOG_UI.md` - every frontend surface, page, and launcher across your GitHub Pages estate

## 10. Second Layer: IBM and Enterprise Language Stack

This is not the live Codex tool surface. It is the second conceptual layer you asked to track: enterprise execution languages, automation languages, and orchestration DNA worth borrowing.

## 11. IBM Mainframe and Enterprise Languages

| Language | Purpose |
|---|---|
| COBOL | Enterprise business systems, banking, insurance, government workloads |
| REXX | Automation scripts, system utilities, TSO commands, ISPF tooling |
| JCL | Defines and runs batch jobs, controls datasets and execution flow |
| PL/I | Scientific, engineering, and enterprise applications |
| HLASM | Low-level system programming, hardware interaction |
| C / C++ | Systems programming and enterprise applications on z/OS |
| Java | Enterprise applications, APIs, and web workloads on IBM systems |

## 12. IBM Automation and Scripting Languages

| Language | Purpose |
|---|---|
| REXX | Mainframe automation scripting |
| CLIST | Older TSO command scripting language |
| Python | Modern automation, AI, cloud, and DevOps tooling |
| JavaScript / Node.js | Web tools, APIs, and automation services |
| Shell scripting | Linux and AIX automation |

## 13. IBM i (AS/400) Languages

| Language | Purpose |
|---|---|
| RPG / RPGLE | Business applications on IBM i |
| CL (Control Language) | IBM i system automation |
| COBOL | Business workloads |
| C / C++ | System and application development |
| Java | Modern IBM i applications |
| SQL PL | Database procedures |

## 14. IBM Database and Data Languages

| Language | Purpose |
|---|---|
| SQL | DB2 databases |
| SQL PL | Stored procedures and database logic |
| SPUFI commands | DB2 interactive SQL tooling |
| QMF scripting | Query and report automation |

## 15. IBM Legacy and Specialized Languages

| Language | Purpose |
|---|---|
| Easytrieve | Report generation and data processing |
| Natural | Enterprise application development, often alongside IBM environments |
| Assembler | Hardware-level programming |
| BASIC / Pascal | Historical IBM platforms |

## 16. Orchestration DNA to Borrow

If the goal is an agent orchestration language with mainframe discipline, the useful borrow points are:

| Source | Borrowed strength |
|---|---|
| REXX | readable automation rules |
| JCL | workflow and job orchestration |
| Regex | pattern matching and event detection |
| COBOL | strong data structures and business rules |
| SQL | state and memory queries |
| Assembler or Rust-style execution | deterministic low-level execution |

That gives you a design direction closer to:

- REXX-style readable control flow
- JCL-style execution staging and dispatch
- regex-driven routing and extraction
- COBOL-style record discipline
- SQL-backed state access
- deterministic kernel execution under a tighter systems layer

In plain terms: a modern agent language shaped like `REXX + JCL + regex + typed systems core`.

## 17. Third Layer: GPU, NVIDIA, and Parallel Compute Stack

This layer tracks the compute-side execution model that complements the IBM enterprise control layer.

## 18. GPU and CUDA Programming

| Language / Layer | Use |
|---|---|
| CUDA C/C++ | NVIDIA's primary GPU programming model; write kernels that run directly on GPUs |
| CUDA Fortran | GPU acceleration for scientific computing |
| PTX | NVIDIA's low-level virtual assembly language for GPUs |
| SASS | Actual NVIDIA GPU machine instructions |

Example CUDA kernel:

```cpp
__global__ void add(int *a, int *b, int *c) {
    int i = threadIdx.x;
    c[i] = a[i] + b[i];
}
```

## 19. AI and Machine Learning Stack

| Language / Layer | Use |
|---|---|
| Python | Dominant AI development language |
| C++ | Framework backends, inference engines, and high performance runtime code |
| CUDA Python | Python interface to CUDA |
| Triton | GPU kernel programming language created by OpenAI, widely used with NVIDIA GPUs |
| PyTorch (Python/C++) | Deep learning framework heavily optimized for NVIDIA GPUs |

## 20. NVIDIA Hardware and System Languages

| Language / Layer | Use |
|---|---|
| Verilog / SystemVerilog | Designing digital hardware and chips |
| VHDL | Hardware description, less common in NVIDIA workflows |
| C | Embedded systems, firmware, and drivers |
| C++ | Drivers, runtimes, robotics, and graphics systems |

## 21. Graphics and Simulation Languages

| Language / Layer | Use |
|---|---|
| GLSL | GPU shader programming |
| HLSL | Graphics shaders in the DirectX ecosystem |
| OpenCL C | General GPU computing |
| OptiX programs | Ray tracing development |
| USD / Python | 3D scenes and simulation workflows |

## 22. Robotics and Autonomous Systems

| Language / Layer | Use |
|---|---|
| Python | AI pipelines and robotics scripts |
| C++ | Real-time robotics systems |
| CUDA | Accelerated perception and simulation |
| ROS (C++/Python) | Robot operating system stack |

## 23. NVIDIA Stack DNA

If the IBM side is:

- JCL -> orchestrate jobs
- REXX -> automate systems
- COBOL -> process business logic

Then the NVIDIA side is closer to:

- CUDA -> orchestrate computation
- PTX -> control GPU execution
- tensor compute -> accelerate AI math
- Python -> compose intelligence

For an agent language or agent OS, the NVIDIA-inspired borrow points are:

| Source | Borrowed strength |
|---|---|
| CUDA | parallel agent execution |
| PTX | low-level agent instructions |
| tensor compute | accelerated inference and scoring |
| Triton | custom AI kernel paths |
| Python | AI model composition and tooling |
| C++ / Rust style runtime discipline | deterministic high-performance execution |

## 24. Plasma Mamba 8B Combo Architecture

This is the synthesized architecture using the IBM control layer, NVIDIA compute layer, and modern model-architecture layer.

### Core thesis

The clean split is:

- IBM-style languages define workflow, governance, business logic, and batch discipline
- NVIDIA-style layers define parallel compute, accelerated inference, and low-level execution
- modern model architectures define reasoning, memory, specialization, and routing

### Model architecture layer

| Architecture | Role in the stack |
|---|---|
| Transformer | reasoning, attention, tool selection, structured generation |
| Mamba / SSM | persistent sequence memory, long-context efficiency, state tracking |
| MoE | specialist activation without paying full dense-model cost |
| RWKV / hybrid recurrent forms | lightweight persistent state and streaming behavior |

### Plasma Mamba 8B layout

`Plasma Mamba 8B` should be treated as a hybrid agent core, not a pure single-architecture bet.

Recommended split:

| Layer | Recommended role |
|---|---|
| Transformer block | deliberate reasoning, instruction following, synthesis |
| Mamba block | long-running memory, state carry, efficient context digestion |
| MoE routing head | specialist agent dispatch and domain specialization |
| CUDA / Triton kernels | accelerated inference and scoring paths |
| PTX-like intermediate layer | low-level deterministic agent instruction form |

### System architecture mapping

| System concern | Best fit |
|---|---|
| Agent interfaces | TypeScript or C# |
| Distributed runtime | Go |
| Secure execution core | Rust |
| AI tools and orchestration glue | Python |
| Enterprise workflow and policy | REXX + JCL + COBOL style design |
| State and memory | SQL + graph database |
| Accelerated intelligence layer | CUDA / Triton / tensor compute |

### SnapKitty-style control stack

A coherent control stack using your framing looks like this:

1. `JCL-style orchestration layer`
   - batch scheduling
   - staged workflow dispatch
   - job graph execution

2. `REXX-style readable automation layer`
   - policy rules
   - operator-readable control scripts
   - glue between modules

3. `Regex/event routing layer`
   - trigger detection
   - pattern classification
   - message and document extraction

4. `COBOL-style business rules layer`
   - record discipline
   - claims, law, finance, trust, and audit data structures
   - deterministic business logic

5. `Transformer reasoning layer`
   - synthesis
   - explanation
   - planning
   - tool choice

6. `Mamba memory layer`
   - persistent state tracking
   - long-range context compression
   - efficient sequence retention

7. `MoE specialist layer`
   - legal specialist
   - finance specialist
   - audit specialist
   - code specialist

8. `CUDA / Triton execution layer`
   - accelerated kernels
   - high-throughput inference
   - parallel scoring and dispatch

9. `PTX-like substrate layer`
   - compact intermediate instructions
   - deterministic execution target
   - future-proof backend portability

### Practical reading

If you want one sentence for the architecture:

`Plasma Mamba 8B = Transformer reasoning + Mamba memory + MoE specialization + CUDA-class execution under an IBM-style orchestration shell.`

That is the version that makes technical sense. It avoids random language sprawl and gives each layer a job.

## 25. Layer 4: Repo-to-Architecture Module Map

This layer answers three questions:
- which language belongs in which repo
- which layer belongs in frontend vs backend vs kernel
- what should be experimental vs production core

### Production core β€” never changes without a deed amendment

These are the kernel layer. Deterministic, WORM-sealed, no side effects that aren't auditable.

| Repo / File | Language | Layer | Role |
|---|---|---|---|
| `cartographer-agent/kernels/rexx-glue-kernel.rexx` | REXX | Kernel | Business action dispatch β€” 15 legal actions |
| `cartographer-agent/kernels/route-dispatch.rexx` | REXX | Kernel | Pattern match β†’ kernel chain |
| `sovereign-glue.rexx` | REXX | Kernel | Master glue β€” domain detect β†’ full chain |
| `cartographer-agent/kernels/carto-gate.lp` | ASP/Clingo | Kernel | Constitutional constraint β€” UNSAT on violation |
| `cartographer-agent/prolog/carto.pl` | Prolog | Kernel | Standing logic β€” pure Horn clauses |
| `bobs-control-repo/.../sovereign-alien-trust.pl` | Prolog | Kernel | Trust deed axioms β€” 13 rules, adversarial detection |
| `cartographer-agent/kernels/cobol-law-kernel.cob` | COBOL | Kernel | Financial transaction law |
| `cartographer-agent/runtime/dfa-engine.mjs` | JS | Kernel | O(n) tokenizer β€” PTX substrate of the stack |
| `mathrosetta/src/dispatcher.rs` | Rust | Kernel | Math solver routing β€” Z3/Lean4/Julia/SymPy |
| `mathrosetta/src/worm/chain.rs` | Rust | Kernel | WORM chain β€” Mamba memory equivalent |
| `snapkitty-chain/src/chain.mjs` | JS | Kernel | P2P chain β€” consensus, ZK, mempool |

### Backend runtime β€” stable but evolvable

These serve requests, translate between layers, and orchestrate kernel calls.

| Repo / File | Language | Layer | Role |
|---|---|---|---|
| `agentos/src/sovereign-daemon/main.go` | Go | Backend | HTTP daemon β€” execute, sign, validate endpoints |
| `cartographer-agent/runtime/corpus_store.ml` | OCaml | Backend | Knowledge retrieval β€” 9-chapter law corpus |
| `cartographer-agent/runtime/route-dispatch.mjs` | JS | Backend | JS mirror of REXX router β€” used by browser UI |
| `cartographer-agent/runtime/trust-deed-generator.mjs` | JS | Backend | Deed forge β€” EIN β†’ Prolog + plain English deed |
| `cartographer-agent/runtime/summon-envelope.mjs` | JS | Backend | Agent summon envelope β€” WORM-sealed dispatch |
| `workers/meta-webhook.js` | JS (Cloudflare Worker) | Backend | Meta webhook receiver β€” KV store + /feed endpoint |
| `kernel-registry.json` | JSON | Backend | Registry β€” every kernel's path, invoke, domain, complexity |

### Frontend β€” ephemeral, agent-facing, user translation layer

The agent is only alive here. Dies at session end. The kernel persists. The deed persists. The UI does not.

| Repo / File | Language | Layer | Role |
|---|---|---|---|
| `cartographer-agent/docs/mylaw.html` | HTML/JS/Tau Prolog | Frontend | MyLaw β€” Facebook 2009 UI, BOB messenger, wall posts |
| `cartographer-agent/docs/carto-live.html` | HTML/JS/Tau Prolog | Frontend | CARTO engine β€” developer-facing, purple/gold theme |
| `cartographer-agent/docs/shakespearean-code.html` | HTML/JS | Frontend | Shakespearean DSL demo |
| `mathrosetta/src/wasm.rs` | Rust β†’ WASM | Frontend | Math IR in browser β€” Rust compiled to WASM |
| `.newrepos/snapkitty-clojure-lisp-bridge/` | Clojure/ClojureScript | Frontend | Lisp/symbolic wire format β€” inter-agent protocol |

### Experimental β€” not production, high upside

These are research beds. Real assets but not load-bearing yet.

| Repo / File | Language | Layer | Role |
|---|---|---|---|
| `mathrosetta/src/emitters/lean4.rs` | Rust | Experimental | Lean4 proof output β€” full certificate generation |
| `mathrosetta/src/emitters/coq.rs` | Rust | Experimental | Coq output β€” alternative proof backend |
| `mathrosetta/src/nlp/mod.rs` | Rust | Experimental | NaturalParser β€” phrase β†’ MathIR, 11 phrases wired |
| `prism-skills/` | Various | Experimental | PSI pipeline β€” admission, canonical, seal, sha256d |
| `qec-discovery/` | APL + Fortran | Experimental | Quantum error correction research |
| `pnp-attack/` | APL + Fortran | Experimental | P≠NP formal attack — not a claim, a proof attempt |
| `resonance-math/` | Various | Experimental | Resonance axiom system |
| `.qwen/skills/` | Various | Experimental | Qwen skill pack β€” 9 auto-skills for routing tests |
| `S_AUTOCODE/` | Various | Experimental | AUTOCODE lineage β€” the origin system |

### What this means for build prioritization

Three rules from this map:

**Rule 1: Never Python in the kernel layer.**
Python belongs in the NVIDIA/AI tooling layer (training, fine-tuning, embeddings). It does not belong in the REXX/Prolog/COBOL kernel chain. The kernel must be deterministic and auditable. Python is not that.

**Rule 2: The frontend is the translation layer. It is not the product.**
mylaw.html, carto-live.html β€” these are how humans touch the kernels. The kernels are the product. The UI can be rebuilt in an afternoon. The sovereign-alien-trust.pl took months.

**Rule 3: Experimental repos are batteries. Production repos are the circuit.**
qec-discovery, pnp-attack, resonance-math β€” these are energy storage. They prove mathematical properties that will eventually flow into the kernel layer as new axioms. Don't rush them into production. Let them complete their proofs first.

### The one sentence this all reduces to

`The kernel layer computes truth. The backend layer routes it. The frontend layer translates it. The agent reads the translation and dies. The WORM chain remembers everything.`

That is the full architecture. IBM gave us the orchestration discipline. NVIDIA gave us the execution speed. Mamba gave us the memory model. SnapKitty gave us the deed that governs it all.